import Foundation

enum HeaderType: String {

    /**
     The standard page header, left-aligned
     */
    case left

    /**
     The standard overview header, centered
     */
    case center

    /**
     The element provides it's own header, so don't generate any.
     */
    case none
}

extension HeaderType: StringProperty {

    init?(_ value: String) {
        self.init(rawValue: value)
    }

    static var castFailureReason: String {
        "Header type must be 'left', 'center' or 'none'"
    }
}

extension HeaderType: DefaultValueProvider {

    static var defaultValue: HeaderType { .left }
}
